==> PDFlib-Lite-7.0.2p8.tar.gz: PDFlib-Lite-7.0.2p8/bind/pdflib/perl/starter_pdfa.pl <==
#!/usr/bin/perl
# $Id: starter_pdfa.pl,v 1.2 2006/10/01 19:55:11 rjs Exp $
#
# PDF/A starter:
# Create PDF/A-compliant output
#
# required software: PDFlib/PDFlib+PDI/PPS 7
# required data: font file, image file

use pdflib_pl 7.0;

# This is where the data files are. Adjust as necessary.
$searchpath = "../data";
$imagefile = "nesrin.jpg";
$outfilename = "starter_pdfa.pdf";

$p = PDF_new();

eval {
    # This means we must check return values of load_font() etc.
    PDF_set_parameter($p, "errorpolicy", "return");

    PDF_set_parameter($p, "SearchPath", $searchpath);

    # we use "utf8" as textformat, this allows to use unicode encoding
    PDF_set_parameter($p, "textformat", "utf8");

    # PDF/A-1a requires Tagged PDF
    if (PDF_begin_document($p, $outfilename, "pdfa=PDF/A-1b:2005") == -1) {
	die("Error: " . PDF_get_errmsg($p));
    }

    #
    # We use sRGB as output intent since it allows the color
    # spaces CIELab, ICC-based, grayscale, and RGB.
    #
    # If you need CMYK color you must use a CMYK output profile.
    

    PDF_load_iccprofile($p, "sRGB", "usage=outputintent");

    PDF_set_info($p, "Creator", "PDFlib starter sample");
    PDF_set_info($p, "Title", "starter_pdfa");

    PDF_begin_page_ext($p, 595, 842, "");

    # $font embedding is required for PDF/A
    $font = PDF_load_font($p, "LuciduxSans-Oblique", "unicode", "embedding");
    if ($font == -1) {
	die("Error: %s\n", PDF_get_errmsg($p));
    }
    PDF_setfont($p, $font, 24);

    PDF_fit_textline($p, "PDF/A-1b:2005 starter", 50, 700, "");

    # We can use an RGB $image since we already supplied an
    # output intent profile.
    
    $image = PDF_load_image($p, "auto", $imagefile, "");
    if ($image == -1) {
	die("Error: " . PDF_get_errmsg($p));
    }

    # Place the $image at the bottom of the page
    PDF_fit_image($p, $image, 0.0, 0.0, "scale=0.5");

    PDF_end_page_ext($p, "");

    PDF_end_document($p, "");

    PDF_delete($p);
};

if ($@) {
    printf("hello: PDFlib Exception occurred:\n");
    printf(" $@\n");
    exit;
}

==> PDFlib-Lite-7.0.5.tar.gz: PDFlib-Lite-7.0.5/bind/pdflib/perl/starter_pdfa.pl <==
#!/usr/bin/perl
# $Id: starter_pdfa.pl,v 1.2.2.1 2008/12/25 13:28:41 rp Exp $
#
# PDF/A starter:
# Create PDF/A-compliant output
#
# required software: PDFlib/PDFlib+PDI/PPS 7
# required data: font file, image file

use pdflib_pl 7.0;

# This is where the data files are. Adjust as necessary.
$searchpath = "../data";
$imagefile = "nesrin.jpg";
$outfilename = "starter_pdfa.pdf";

$p = PDF_new();

eval {
    # This means we must check return values of load_font() etc.
    PDF_set_parameter($p, "errorpolicy", "return");

    PDF_set_parameter($p, "SearchPath", $searchpath);

    # we use "utf8" as textformat, this allows to use unicode encoding
    PDF_set_parameter($p, "textformat", "utf8");

    # PDF/A-1a requires Tagged PDF
    if (PDF_begin_document($p, $outfilename, "pdfa=PDF/A-1b:2005") == -1) {
	die("Error: " . PDF_get_errmsg($p));
    }

    #
    # We use sRGB as output intent since it allows the color
    # spaces CIELab, ICC-based, grayscale, and RGB.
    #
    # If you need CMYK color you must use a CMYK output profile.
    

    PDF_load_iccprofile($p, "sRGB", "usage=outputintent");

    PDF_set_info($p, "Creator", "PDFlib starter sample");
    PDF_set_info($p, "Title", "starter_pdfa");

    PDF_begin_page_ext($p, 595, 842, "");

    # $font embedding is required for PDF/A
    $font = PDF_load_font($p, "LuciduxSans-Oblique", "unicode", "embedding");
    if ($font == -1) {
	die("Error: %s\n", PDF_get_errmsg($p));
    }
    PDF_setfont($p, $font, 24);

    PDF_fit_textline($p, "PDF/A-1b:2005 starter", 50, 700, "");

    # We can use an RGB $image since we already supplied an
    # output intent profile.
    
    $image = PDF_load_image($p, "auto", $imagefile, "");
    if ($image == -1) {
	die("Error: " . PDF_get_errmsg($p));
    }

    # Place the $image at the bottom of the page
    PDF_fit_image($p, $image, 0.0, 0.0, "scale=0.5");

    PDF_end_page_ext($p, "");

    PDF_end_document($p, "");

    PDF_delete($p);
};

if ($@) {
    printf("starter_pdfa: PDFlib Exception occurred:\n");
    printf(" $@\n");
    exit;
}
